Installation
============

The Invenio-DB package is on PyPI so all you need is:

.. code-block:: console

    $ pip install invenio-db

Invenio Asssets depends on Flask-SQLAlchemy.


Configuration
=============

* ``SQLALCHEMY_DATABASE_URI``
* ``SQLALCHEMY_ECHO``
